# Changelog

<!--next-version-placeholder-->

## v0.1.36 (2021-01-27)
### Fix
* **admin:** Another try ([`e592500`](https://github.com/dominikkarall/fhempy/commit/e592500ba431e5bd112e594f38b9a96f2bb0e65d))

## v0.1.35 (2021-01-27)
### Fix
* **setup:** Fix excludes in manifest ([`9c3b255`](https://github.com/dominikkarall/fhempy/commit/9c3b255e90fbc8c8f0ab11a85531795c6239fd84))

## v0.1.34 (2021-01-27)
### Fix
* **readme:** Another fix ([`fc11bc4`](https://github.com/dominikkarall/fhempy/commit/fc11bc4426023161c219b2ea7b3daedf9f9696a6))

## v0.1.33 (2021-01-27)
### Fix
* **release:** One more try to get gh token working ([`f7f0f04`](https://github.com/dominikkarall/fhempy/commit/f7f0f04443b9b2a05d05dbb8bd76cc46132a8f70))

## v0.1.32 (2021-01-27)
### Fix
* **release:** Hopefully fix release script ([`cea2a16`](https://github.com/dominikkarall/fhempy/commit/cea2a165abd64ac7410ecb387dbf1d36f50cb468))

## v0.1.31 (2021-01-27)
### Feature
* **tuya:** Add keep_connected attr ([`b2c1ca4`](https://github.com/dominikkarall/fhempy/commit/b2c1ca47cf1b7adda9eb86731f21e0f755cf3dcd))

## v0.1.30 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Remove unused imports ([`1758909`](https://github.com/dominikkarall/fhem_pythonbinding/commit/175890932f4efeeedba79ae6b2d1dfe81839abcc))

## v0.1.29 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Add import time ([`7ef7a9e`](https://github.com/dominikkarall/fhem_pythonbinding/commit/7ef7a9ecabb2e8f765f6e1223bcaaaed365c6644))
* **xiaomi_gateway3:** Set last_update on update ([`146487d`](https://github.com/dominikkarall/fhem_pythonbinding/commit/146487daf69f9ed5219043c444fdfbac9f90021c))

## v0.1.28 (2021-01-27)
### Feature
* New reading pairing on/off ([`ee42b9c`](https://github.com/dominikkarall/fhem_pythonbinding/commit/ee42b9c1dc822993ee882e94be056b311f87bd8e))

## v0.1.27 (2021-01-27)
### Fix
* Pychromecast min version ([`8a58a53`](https://github.com/dominikkarall/fhem_pythonbinding/commit/8a58a5374c25ffcaf1f3c9a9f37b5ebb83272d96))
